cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;
return plural;
},
  "language": "uk",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Додати запис"
 ],
 "Add on build variable": [
  null,
  "Додати змінну збирання"
 ],
 "All": [
  null,
  "Усі"
 ],
 "All registries": [
  null,
  "Усі реєстри"
 ],
 "An error occured": [
  null,
  "Сталася помилка"
 ],
 "Author": [
  null,
  "Автор"
 ],
 "Automatically start podman on boot": [
  null,
  "Автоматично запускати podman під час завантаження"
 ],
 "CPU": [
  null,
  "Процесор"
 ],
 "CPU shares": [
  null,
  "Спільне використання процесора"
 ],
 "Cancel": [
  null,
  "Скасувати"
 ],
 "Checkpoint": [
  null,
  "Контрольна точка"
 ],
 "Checkpoint container $0": [
  null,
  "Контрольна точка контейнера $0"
 ],
 "Command": [
  null,
  "Команда"
 ],
 "Commit": [
  null,
  "Надіслати"
 ],
 "Commit image": [
  null,
  "Надіслати образ"
 ],
 "Console": [
  null,
  "Консоль"
 ],
 "Container": [
  null,
  "Контейнер"
 ],
 "Container failed to be created": [
  null,
  "Не вдалося створити контейнер"
 ],
 "Container failed to be started": [
  null,
  "Не вдалося запустити контейнер"
 ],
 "Container is currently running.": [
  null,
  "Контейнер працює."
 ],
 "Container is not running": [
  null,
  "Контейнер не запущено"
 ],
 "Container name": [
  null,
  "Назва контейнера"
 ],
 "Container path": [
  null,
  "Шлях до контейнера"
 ],
 "Container port": [
  null,
  "Порт контейнера"
 ],
 "Containers": [
  null,
  "Контейнери"
 ],
 "Created": [
  null,
  "Створено"
 ],
 "Delete": [
  null,
  "Вилучити"
 ],
 "Delete $0": [
  null,
  "Вилучити $0"
 ],
 "Delete image": [
  null,
  "Вилучити зображення"
 ],
 "Delete tagged images": [
  null,
  "Вилучити позначені міткою образи"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Вилучення контейнера призведе до витирання усіх даних, що на ньому зберігаються."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Вилучення цього кокону призведе до вилучення таких контейнерів:"
 ],
 "Details": [
  null,
  "Подробиці"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Не включати зміни у кореневій файловій системі при експортуванні"
 ],
 "Download": [
  null,
  "Отримати"
 ],
 "Entrypoint": [
  null,
  "Точка входження"
 ],
 "Environment": [
  null,
  "Середовище"
 ],
 "Error": [
  null,
  "Помилка"
 ],
 "Error message": [
  null,
  "Повідомлення про помилку"
 ],
 "Error occured while connecting console": [
  null,
  "Під час спроби встановити з'єднання з консоллю сталася помилка"
 ],
 "Exited": [
  null,
  "Вийшов"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Не вдалося створити контрольну точку контейнера $0"
 ],
 "Failed to commit container $0": [
  null,
  "Не вдалося надіслати на обробку контейнер $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Не вдалося отримати образ $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Не вдалося примусово вилучити контейнер $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Не вдалося примусово зупинити кокон $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Не вдалося призупинити кокон $0"
 ],
 "Failed to remove container $0": [
  null,
  "Не вдалося вилучити контейнер $0"
 ],
 "Failed to restart container $0": [
  null,
  "Не вдалося перезапустити контейнер $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Не вдалося перезапустити кокон $0"
 ],
 "Failed to restore container $0": [
  null,
  "Не вдалося відновити контейнер $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Не вдалося відновити кокон $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Не вдалося виконати пошук образів: $0"
 ],
 "Failed to search for new images": [
  null,
  "Не вдалося виконати пошук нових образів"
 ],
 "Failed to start container $0": [
  null,
  "Не вдалося запустити роботу контейнера $0"
 ],
 "Failed to start pod $0": [
  null,
  "Не вдалося запустити кокон $0"
 ],
 "Failed to stop container $0": [
  null,
  "Не вдалося зупинити роботу контейнера $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Не вдалося зупинити кокон $0"
 ],
 "Force delete": [
  null,
  "Примусове вилучення"
 ],
 "Force restart": [
  null,
  "Примусовий перезапуск"
 ],
 "Force stop": [
  null,
  "Примусово зупинити"
 ],
 "Format": [
  null,
  "Формат"
 ],
 "Gateway": [
  null,
  "Шлюз"
 ],
 "Get new image": [
  null,
  "Отримати новий образ"
 ],
 "GiB": [
  null,
  "ГіБ"
 ],
 "Hide intermediate images": [
  null,
  "Приховати проміжні образи"
 ],
 "Host path": [
  null,
  "Шлях у основній системі"
 ],
 "Host port (optional)": [
  null,
  "Порт основної системи (необов'язковий)"
 ],
 "ID": [
  null,
  "Ід."
 ],
 "IP (optional)": [
  null,
  "IP-адреса (необов'язкова)"
 ],
 "IP address": [
  null,
  "IP-адреса"
 ],
 "IP prefix length": [
  null,
  "Довжина префікса IP"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ігнорувати IP-адресу, якщо її встановлено статично"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ігнорувати MAC-адресу, якщо її встановлено статично"
 ],
 "Image": [
  null,
  "Зображення"
 ],
 "Image name": [
  null,
  "Назви предметів"
 ],
 "Images": [
  null,
  "Зображення"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Зберігати усі тимчасові файли контрольних точок"
 ],
 "Key": [
  null,
  "Ключ"
 ],
 "KiB": [
  null,
  "КіБ"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Лишати запущеним після запису контрольної точки на диск"
 ],
 "Loading logs...": [
  null,
  "Завантаження журналу…"
 ],
 "Loading...": [
  null,
  "Завантаження…"
 ],
 "Logs": [
  null,
  "Журнал"
 ],
 "MAC address": [
  null,
  "MAC-адреса"
 ],
 "Memory": [
  null,
  "Пам'ять"
 ],
 "Memory limit": [
  null,
  "Обмеження пам’яті"
 ],
 "Message": [
  null,
  "Повідомлення"
 ],
 "MiB": [
  null,
  "МіБ"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Для цього образу існує декілька міток. Виберіть позначені міткою образи для вилучення."
 ],
 "Name": [
  null,
  "Назва"
 ],
 "No SELinux label": [
  null,
  "Без мітки SELinux"
 ],
 "No containers": [
  null,
  "Немає контейнерів"
 ],
 "No containers are using this image": [
  null,
  "Цей образ не використовує жоден контейнер"
 ],
 "No containers in this pod": [
  null,
  "У цьому коконі немає контейнерів"
 ],
 "No containers that match the current filter": [
  null,
  "Немає контейнерів, які проходять поточні умови фільтрування"
 ],
 "No images": [
  null,
  "Немає образів"
 ],
 "No images found": [
  null,
  "Образів не знайдено"
 ],
 "No images that match the current filter": [
  null,
  "Немає образів, які проходять поточні умови фільтрування"
 ],
 "No results for $0": [
  null,
  "Немає результатів, що відповідають $0"
 ],
 "No running containers": [
  null,
  "Немає запущених контейнерів"
 ],
 "Only running": [
  null,
  "Лише запущені"
 ],
 "Owner": [
  null,
  "Власник"
 ],
 "Pause": [
  null,
  "Призупинити"
 ],
 "Pause the container": [
  null,
  "Призупинити роботу контейнера"
 ],
 "Paused": [
  null,
  "Призупинено"
 ],
 "Please confirm deletion of $0": [
  null,
  "Будь ласка, підтвердьте вилучення $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Будь ласка, підтвердьте вилучення кокона $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Будь ласка, підтвердьте примусове вилучення кокона $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Будь ласка, підтвердьте примусове вилучення $0"
 ],
 "Please retry another term.": [
  null,
  "Будь ласка, повторіть спробу із іншим ключем пошуку."
 ],
 "Please start typing to look for images.": [
  null,
  "Будь ласка, почніть щось вводити, щоб виконати пошук образів."
 ],
 "Podman containers": [
  null,
  "Контейнери Podman"
 ],
 "Podman service is not active": [
  null,
  "Служба Podman є неактивною"
 ],
 "Ports": [
  null,
  "Порти"
 ],
 "Private": [
  null,
  "Приватний"
 ],
 "Pulling": [
  null,
  "Отримання даних"
 ],
 "ReadOnly": [
  null,
  "Лише читання"
 ],
 "ReadWrite": [
  null,
  "Запис-читання"
 ],
 "Remove item": [
  null,
  "Вилучити запис"
 ],
 "Remove on build variable": [
  null,
  "Встановити змінну збирання"
 ],
 "Restart": [
  null,
  "Перезапустити"
 ],
 "Restore": [
  null,
  "Відновити"
 ],
 "Restore container $0": [
  null,
  "Відновити контейнер $0"
 ],
 "Restore with established TCP connections": [
  null,
  "Відновити із встановленими з'єднаннями TCP"
 ],
 "Resume": [
  null,
  "Продовжити"
 ],
 "Run": [
  null,
  "Запустити"
 ],
 "Run image": [
  null,
  "Запустити образ"
 ],
 "Running": [
  null,
  "Запущено"
 ],
 "Search by name or description": [
  null,
  "Шукати за назвою і описом"
 ],
 "Search for": [
  null,
  "Шукати"
 ],
 "Search for an image": [
  null,
  "Шукати образ"
 ],
 "Searching...": [
  null,
  "Пошук…"
 ],
 "Set container on build variables": [
  null,
  "Встановити змінні збирання контейнера"
 ],
 "Shared": [
  null,
  "Спільний"
 ],
 "Show": [
  null,
  "Показати"
 ],
 "Show intermediate images": [
  null,
  "Показати проміжні образи"
 ],
 "Size": [
  null,
  "Розмір"
 ],
 "Start": [
  null,
  "Запустити"
 ],
 "Start podman": [
  null,
  "Запустити podman"
 ],
 "State": [
  null,
  "Стан"
 ],
 "Stop": [
  null,
  "Зупинити"
 ],
 "Stopped": [
  null,
  "Зупинено"
 ],
 "Support preserving established TCP connections": [
  null,
  "Підтримка збереження встановлених з'єднань TCP"
 ],
 "System": [
  null,
  "Система"
 ],
 "System Podman service is also available": [
  null,
  "Також доступна загальносистемна служба Podman"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Мітка"
 ],
 "Tags": [
  null,
  "Мітки"
 ],
 "Troubleshoot": [
  null,
  "Діагностика проблем"
 ],
 "Type to filter…": [
  null,
  "Введіть щось для фільтрування…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Працює з $0"
 ],
 "Used by": [
  null,
  "Використовується"
 ],
 "User": [
  null,
  "Користувач"
 ],
 "User Podman service is also available": [
  null,
  "Також доступна служба користувачів Podman"
 ],
 "Value": [
  null,
  "Значення"
 ],
 "Volumes": [
  null,
  "Томи"
 ],
 "With terminal": [
  null,
  "За допомогою термінала"
 ],
 "configured": [
  null,
  "налаштовано"
 ],
 "container": [
  null,
  "контейнер"
 ],
 "created": [
  null,
  "створено"
 ],
 "exited": [
  null,
  "здійснено вихід"
 ],
 "image": [
  null,
  "образ"
 ],
 "in": [
  null,
  "у"
 ],
 "n/a": [
  null,
  "н/д"
 ],
 "not available": [
  null,
  "не доступне"
 ],
 "paused": [
  null,
  "призупинено"
 ],
 "pod group": [
  null,
  "група коконів"
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "вилучення"
 ],
 "running": [
  null,
  "працює"
 ],
 "select all": [
  null,
  "вибрати все"
 ],
 "stopped": [
  null,
  "зупинився"
 ],
 "system": [
  null,
  "система"
 ]
});
