cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "pt_PT",
  "x-generator": "Weblate 4.1.1"
 },
 "Add item": [
  null,
  "Adicionar item"
 ],
 "Add on build variable": [
  null,
  "Adicionar nas variáveis de criação"
 ],
 "All": [
  null,
  "Tudo"
 ],
 "All registries": [
  null,
  "Todos os registos"
 ],
 "An error occured": [
  null,
  "Ocorreu um erro"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Iniciar automaticamente o ''podman'' ao inicializar"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "Partilhas de CPU"
 ],
 "Cancel": [
  null,
  "Cancelar"
 ],
 "Checkpoint": [
  null,
  "Posto de controlo"
 ],
 "Checkpoint container $0": [
  null,
  "Verificar ''container'' $0"
 ],
 "Command": [
  null,
  "Comando"
 ],
 "Commit": [
  null,
  "Implementar"
 ],
 "Commit image": [
  null,
  "Implementar imagem"
 ],
 "Console": [
  null,
  "Consola"
 ],
 "Container": [
  null,
  "'Container'"
 ],
 "Container failed to be created": [
  null,
  "Não foi possível criar 'Container'"
 ],
 "Container failed to be started": [
  null,
  "Não foi possível criar o 'container'"
 ],
 "Container is currently running.": [
  null,
  "'Container' está em execução."
 ],
 "Container is not running": [
  null,
  "'Container' não está em execução."
 ],
 "Container name": [
  null,
  "Nome do 'Container'"
 ],
 "Container path": [
  null,
  "Caminho do 'Container'"
 ],
 "Container port": [
  null,
  "Porta do 'Container'"
 ],
 "Containers": [
  null,
  "'Containers'"
 ],
 "Created": [
  null,
  "Criado"
 ],
 "Delete": [
  null,
  "Eliminar"
 ],
 "Delete $0": [
  null,
  "Eliminar $0"
 ],
 "Delete image": [
  null,
  "Eliminar imagem"
 ],
 "Delete tagged images": [
  null,
  "Eliminar imagens marcadas"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Ao eliminar um ''container'' irá limpar todos os dados no mesmo."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Ao eliminar este 'pod' irá remover os seguintes 'containers':"
 ],
 "Details": [
  null,
  "Detalhes"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Não inclua alterações do sistema de ficheiros raiz ao exportar"
 ],
 "Download": [
  null,
  "Transferir"
 ],
 "Entrypoint": [
  null,
  "Ponto de entrada"
 ],
 "Environment": [
  null,
  "Ambiente"
 ],
 "Error": [
  null,
  "Erro"
 ],
 "Error message": [
  null,
  "Mensagem de erro"
 ],
 "Error occured while connecting console": [
  null,
  ""
 ],
 "Exited": [
  null,
  "Saiu"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Falha ao verificar o ''container'' $0"
 ],
 "Failed to commit container $0": [
  null,
  "Não foi possível implementar ''container'' $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Não foi possível transferir a imagem $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Não foi possível forçar a remoção do 'container' $"
 ],
 "Failed to force stop pod $0": [
  null,
  "Falha ao forçar a paragem do 'pod' $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Falha ao pausar o 'pod' $0"
 ],
 "Failed to remove container $0": [
  null,
  "Não foi possível remover o 'container' $0"
 ],
 "Failed to restart container $0": [
  null,
  "Não foi possível reiniciar o 'container' $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Não foi possível reiniciar o 'pod' $0"
 ],
 "Failed to restore container $0": [
  null,
  "Não foi possível restaurar o 'container' $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Falha ao retomar o 'pod' $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Falha ao procurar por imagens: $0"
 ],
 "Failed to search for new images": [
  null,
  "Não foi possível procurar por novas imagens"
 ],
 "Failed to start container $0": [
  null,
  "Não foi possível iniciar o \"container\" $0"
 ],
 "Failed to start pod $0": [
  null,
  "Falha ao iniciar o \"pod\" $0"
 ],
 "Failed to stop container $0": [
  null,
  "Não foi possível para o 'container' $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Falha ao parar o 'pod' $0"
 ],
 "Force delete": [
  null,
  "Forçar Eliminar"
 ],
 "Force restart": [
  null,
  "Forçar Reiniciar"
 ],
 "Force stop": [
  null,
  "Forçar Parar"
 ],
 "Format": [
  null,
  "Formato"
 ],
 "Gateway": [
  null,
  "\"Gateway\""
 ],
 "Get new image": [
  null,
  "Obter nova imagem"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Ocultar imagens intermediárias"
 ],
 "Host path": [
  null,
  "Caminho do anfitrião"
 ],
 "ID": [
  null,
  "Id."
 ],
 "IP (optional)": [
  null,
  ""
 ],
 "IP address": [
  null,
  "Endereço IP"
 ],
 "IP prefix length": [
  null,
  "Tamanho do prefixo do IP"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ignorar o endereço IP, se definido estaticamente"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ignorar o endereço MAC, se definido estaticamente"
 ],
 "Image": [
  null,
  "Imagem"
 ],
 "Image name": [
  null,
  "Nome da Imagem"
 ],
 "Images": [
  null,
  "Imagens"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Manter todos os ficheiros de controlo temporários"
 ],
 "Key": [
  null,
  "Chave"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Deixar em execução após a escrita do ponto de controlo para disco"
 ],
 "Loading logs...": [
  null,
  "A carregar os 'logs'..."
 ],
 "Loading...": [
  null,
  "A carregar..."
 ],
 "Logs": [
  null,
  "\"Logs\""
 ],
 "MAC address": [
  null,
  "Endereço MAC"
 ],
 "Memory": [
  null,
  "Memória"
 ],
 "Memory limit": [
  null,
  "Limite de Memória"
 ],
 "Message": [
  null,
  "Mensagem"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Existem várias etiquetas para esta imagem. Selecione as imagens marcadas com etiqueta para excluir."
 ],
 "Name": [
  null,
  "Nome"
 ],
 "No SELinux label": [
  null,
  "Sem rótulo SELinux"
 ],
 "No containers": [
  null,
  "Sem ''containers''"
 ],
 "No containers are using this image": [
  null,
  "Nenhum ''container'' está a utilizar esta imagem"
 ],
 "No containers in this pod": [
  null,
  "Nenhum ''container'' neste \"pod\""
 ],
 "No containers that match the current filter": [
  null,
  "Nenhum ''container'' corresponde ao filtro atual"
 ],
 "No images": [
  null,
  "Sem imagens"
 ],
 "No images that match the current filter": [
  null,
  "Nenhuma imagem corresponde ao filtro atual"
 ],
 "No results for $0": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Sem ''containers'' em execução"
 ],
 "Only running": [
  null,
  "Apenas a executar"
 ],
 "Owner": [
  null,
  "Dono"
 ],
 "Pause": [
  null,
  "Pausar"
 ],
 "Pause the container": [
  null,
  "Pausar o ''container''"
 ],
 "Paused": [
  null,
  "Em pausa"
 ],
 "Please confirm deletion of $0": [
  null,
  "Por favor, confirme a eliminação de $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Por favor, confirme a eliminação do \"pod\" $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Por favor, confirme a eliminação forçada do \"pod\" $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Por favor, confirme a eliminação forçada de $0"
 ],
 "Please start typing to look for images.": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Podman containers"
 ],
 "Podman service is not active": [
  null,
  "O serviço Podman não está ativo"
 ],
 "Ports": [
  null,
  "Portas"
 ],
 "Private": [
  null,
  "Privado"
 ],
 "Pulling": [
  null,
  "Submissão"
 ],
 "ReadOnly": [
  null,
  "Só de leitura"
 ],
 "ReadWrite": [
  null,
  "Ler Gravar"
 ],
 "Remove item": [
  null,
  "Remover item"
 ],
 "Remove on build variable": [
  null,
  "Remover nas variáveis de criação"
 ],
 "Restart": [
  null,
  "Reiniciar"
 ],
 "Restore": [
  null,
  "Restaurar"
 ],
 "Restore container $0": [
  null,
  "Restaurar o 'container' $0"
 ],
 "Restore with established TCP connections": [
  null,
  "Restaurar com ligações TCP estabelecidas"
 ],
 "Resume": [
  null,
  "Retomar"
 ],
 "Run": [
  null,
  "Executar"
 ],
 "Run image": [
  null,
  "Executar Imagem"
 ],
 "Running": [
  null,
  "A executar"
 ],
 "Search by name or description": [
  null,
  "Procurar por nome ou descrição"
 ],
 "Search for": [
  null,
  "Procurar por"
 ],
 "Search for an image": [
  null,
  "Procurar por uma imagem"
 ],
 "Set container on build variables": [
  null,
  "Definir ''container'' nas variáveis de criação"
 ],
 "Shared": [
  null,
  "Partilhado"
 ],
 "Show": [
  null,
  "Mostrar"
 ],
 "Show intermediate images": [
  null,
  "Mostrar imagens intermediárias"
 ],
 "Size": [
  null,
  "Tamanho"
 ],
 "Start": [
  null,
  "Iniciar"
 ],
 "Start podman": [
  null,
  "Iniciar Podman"
 ],
 "State": [
  null,
  "Estado"
 ],
 "Stop": [
  null,
  "Parar"
 ],
 "Stopped": [
  null,
  "Parado"
 ],
 "Support preserving established TCP connections": [
  null,
  "Suportar preservação das ligações TCP estabelecidas"
 ],
 "System": [
  null,
  "Sistema"
 ],
 "System Podman service is also available": [
  null,
  "Também está disponível o serviço Podman do sistema"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiqueta"
 ],
 "Tags": [
  null,
  "Etiquetas"
 ],
 "Troubleshoot": [
  null,
  "Resolução de problemas"
 ],
 "Type to filter…": [
  null,
  "Digite para filtrar…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Até $0"
 ],
 "Used by": [
  null,
  "Utilizador por"
 ],
 "User": [
  null,
  "Utilizador"
 ],
 "User Podman service is also available": [
  null,
  "Também está disponível o serviço Podman do utilizador"
 ],
 "Value": [
  null,
  "Valor"
 ],
 "Volumes": [
  null,
  "Volumes"
 ],
 "With terminal": [
  null,
  "Com terminal"
 ],
 "configured": [
  null,
  "configurado"
 ],
 "container": [
  null,
  "'container'"
 ],
 "created": [
  null,
  "criado"
 ],
 "exited": [
  null,
  "saiu"
 ],
 "image": [
  null,
  "imagem"
 ],
 "in": [
  null,
  "no"
 ],
 "n/a": [
  null,
  "n/d"
 ],
 "not available": [
  null,
  "indisponível"
 ],
 "paused": [
  null,
  "em pausa"
 ],
 "pod group": [
  null,
  "grupo de \"pods\""
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "a remover"
 ],
 "running": [
  null,
  "a executar"
 ],
 "select all": [
  null,
  "selecionar todos"
 ],
 "stopped": [
  null,
  "parado"
 ],
 "system": [
  null,
  "sistema"
 ]
});
