cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
return plural;
},
  "language": "cs",
  "x-generator": "Weblate 4.1.1"
 },
 "Add item": [
  null,
  "Přidat položku"
 ],
 "Add on build variable": [
  null,
  "Přídatná proměnná prostředí"
 ],
 "All": [
  null,
  "Vše"
 ],
 "All registries": [
  null,
  "Všechny registry"
 ],
 "An error occured": [
  null,
  "Došlo k chybě"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Podman spouštět automaticky při zavádění systému"
 ],
 "CPU": [
  null,
  "Procesor"
 ],
 "CPU shares": [
  null,
  "Sdílení procesoru"
 ],
 "Cancel": [
  null,
  "Storno"
 ],
 "Checkpoint": [
  null,
  "Kontrolní bod"
 ],
 "Checkpoint container $0": [
  null,
  "Kontejner kontrolního bodu $0"
 ],
 "Command": [
  null,
  "Příkaz"
 ],
 "Commit": [
  null,
  "Odeslat"
 ],
 "Commit image": [
  null,
  "Odeslat obraz"
 ],
 "Console": [
  null,
  "Konzole"
 ],
 "Container": [
  null,
  "Kontejner"
 ],
 "Container failed to be created": [
  null,
  "Kontejner se nepodařilo vytvořit"
 ],
 "Container failed to be started": [
  null,
  "Kontejner se nepodařilo spustit"
 ],
 "Container is currently running.": [
  null,
  "Kontejner je nyní spuštěný."
 ],
 "Container is not running": [
  null,
  "Kontejner není spuštěný"
 ],
 "Container name": [
  null,
  "Název kontejneru"
 ],
 "Container path": [
  null,
  "Popis umístění kontejneru"
 ],
 "Container port": [
  null,
  "Port kontejneru"
 ],
 "Containers": [
  null,
  "Kontejnery"
 ],
 "Created": [
  null,
  "Vytvořeno"
 ],
 "Delete": [
  null,
  "Smazat"
 ],
 "Delete $0": [
  null,
  "Smazat $0"
 ],
 "Delete image": [
  null,
  "Smazat obraz"
 ],
 "Delete tagged images": [
  null,
  "Smazat značkou označené obrazy"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Smazání kontejneru smaže veškerá data v něm."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Smazání tohoto podu odebere následující kontejnery:"
 ],
 "Details": [
  null,
  "Podrobnosti"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Do exportu nezahrnovat změny v kořenovém souborovém systému"
 ],
 "Download": [
  null,
  "Stáhnout"
 ],
 "Entrypoint": [
  null,
  "Vstupní bod"
 ],
 "Environment": [
  null,
  "Prostředí"
 ],
 "Error": [
  null,
  "Chyba"
 ],
 "Error message": [
  null,
  "Chybové hlášení"
 ],
 "Error occured while connecting console": [
  null,
  ""
 ],
 "Exited": [
  null,
  "Skončilo"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Kontejner $0 se nepodařilo opatřit kontrolním bodem"
 ],
 "Failed to commit container $0": [
  null,
  "Nepodařilo se odeslat kontejner $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Nepodařilo se stáhnout obraz $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Nepodařilo se vynutit odebrání kontejneru $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Nepodařilo se vynutit zastavení podu $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Nepodařilo se pozastavit pod $0"
 ],
 "Failed to remove container $0": [
  null,
  "Nepodařilo se odebrat kontejner $0"
 ],
 "Failed to restart container $0": [
  null,
  "Nepodařilo se restartovat kontejner $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Nepodařilo se restartovat pod $0"
 ],
 "Failed to restore container $0": [
  null,
  "Nepodařilo se obnovit kontejner $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Nepodařilo se pokračovat v chodu podu $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Nepodařilo se vyhledat obrazy: $0"
 ],
 "Failed to search for new images": [
  null,
  "Nepodařilo se vyhledat nové obrazy"
 ],
 "Failed to start container $0": [
  null,
  "Nepodařilo se spustit kontejner $0"
 ],
 "Failed to start pod $0": [
  null,
  "Nepodařilo se spustit pod $0"
 ],
 "Failed to stop container $0": [
  null,
  "Nepodařilo se spustit kontejner $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Nepodařilo se zastavit pod $0"
 ],
 "Force delete": [
  null,
  "Vynutit smazání"
 ],
 "Force restart": [
  null,
  "Vynutit restart"
 ],
 "Force stop": [
  null,
  "Vynutit zastavení"
 ],
 "Format": [
  null,
  "Formát"
 ],
 "Gateway": [
  null,
  "Brána"
 ],
 "Get new image": [
  null,
  "Získat nový obraz"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Skrýt obrazy mezi tím"
 ],
 "Host path": [
  null,
  "Popis umístění hostitele"
 ],
 "ID": [
  null,
  "Identif."
 ],
 "IP (optional)": [
  null,
  ""
 ],
 "IP address": [
  null,
  "IP adresa"
 ],
 "IP prefix length": [
  null,
  "Délka přepony IP adresy"
 ],
 "Ignore IP address if set statically": [
  null,
  "Pokud je nastavená staticky, IP adresu ignorovat"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Pokud je nastavená staticky, MAC adresu ignorovat"
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image name": [
  null,
  "Název obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Ponechat všechny dočasné soubory kontrolních bodů"
 ],
 "Key": [
  null,
  "Klíč"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Po zapsání kontrolního bodu na disk ponechat spuštěné"
 ],
 "Loading logs...": [
  null,
  "Načítání záznamů událostí…"
 ],
 "Loading...": [
  null,
  "Načítání…"
 ],
 "Logs": [
  null,
  "Záznamy událostí"
 ],
 "MAC address": [
  null,
  "MAC adresa"
 ],
 "Memory": [
  null,
  "Operační paměť"
 ],
 "Memory limit": [
  null,
  "Limit operační paměti"
 ],
 "Message": [
  null,
  "Zpráva"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Pro tento obraz existuje vícero štítků. Vyberte oštítkované obrazy, které smazat."
 ],
 "Name": [
  null,
  "Název"
 ],
 "No SELinux label": [
  null,
  "Žádný SELinux štítek"
 ],
 "No containers": [
  null,
  "Žádné kontejnery"
 ],
 "No containers are using this image": [
  null,
  "Tento obraz není používán žádným kontejnerem"
 ],
 "No containers in this pod": [
  null,
  "V tomto podu nejsou žádné kontejnery"
 ],
 "No containers that match the current filter": [
  null,
  "Stávajícímu filtru neodpovídají žádné kontejnery"
 ],
 "No images": [
  null,
  "Žádné obrazy"
 ],
 "No images that match the current filter": [
  null,
  "Žádné obrazy které by odpovídaly stávajícímu filtru"
 ],
 "No results for $0": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Žádné spuštěné kontejnery"
 ],
 "Only running": [
  null,
  "Pouze spuštěné"
 ],
 "Owner": [
  null,
  "Vlastník"
 ],
 "Pause": [
  null,
  "Pozastavit"
 ],
 "Pause the container": [
  null,
  "Pozastavit kontejner"
 ],
 "Paused": [
  null,
  "Pozastaveno"
 ],
 "Please confirm deletion of $0": [
  null,
  "Potvrďte smazání $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Potvrďte smazání podu $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Potvrďte vynucení smazání podu $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Potvrďte vynucení smazání $0"
 ],
 "Please start typing to look for images.": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Podman kontejnery"
 ],
 "Podman service is not active": [
  null,
  "Služba podman není aktivní"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Private": [
  null,
  "Soukromé"
 ],
 "Pulling": [
  null,
  "Stahování"
 ],
 "ReadOnly": [
  null,
  "PouzeProČtení"
 ],
 "ReadWrite": [
  null,
  "ČetníZápis"
 ],
 "Remove item": [
  null,
  "Odebrat položku"
 ],
 "Remove on build variable": [
  null,
  "Odebrat na proměnných prostředí"
 ],
 "Restart": [
  null,
  "Restart"
 ],
 "Restore": [
  null,
  "Obnovit"
 ],
 "Restore container $0": [
  null,
  "Obnovit kontejner $0"
 ],
 "Restore with established TCP connections": [
  null,
  "Obnovit s navázanými TCP spojeními"
 ],
 "Resume": [
  null,
  "Pokračovat v chodu"
 ],
 "Run": [
  null,
  "Spustit"
 ],
 "Run image": [
  null,
  "Spustit obraz"
 ],
 "Running": [
  null,
  "Spuštěné"
 ],
 "Search by name or description": [
  null,
  "Hledat název nebo popis"
 ],
 "Search for": [
  null,
  "Hledat"
 ],
 "Search for an image": [
  null,
  "Hledat obraz"
 ],
 "Set container on build variables": [
  null,
  "Nastavit kontejner na proměnných prostředí"
 ],
 "Shared": [
  null,
  "Sdílené"
 ],
 "Show": [
  null,
  "Zobrazit"
 ],
 "Show intermediate images": [
  null,
  "Zobrazit obrazy mezi tím"
 ],
 "Size": [
  null,
  "Velikost"
 ],
 "Start": [
  null,
  "Spustit"
 ],
 "Start podman": [
  null,
  "Spustit podman"
 ],
 "State": [
  null,
  "Stav"
 ],
 "Stop": [
  null,
  "Zastavit"
 ],
 "Stopped": [
  null,
  "Zastaveno"
 ],
 "Support preserving established TCP connections": [
  null,
  "Podpora pro zachování navázaných TCP spojení"
 ],
 "System": [
  null,
  "Systém"
 ],
 "System Podman service is also available": [
  null,
  "Systémová služba Podman je k dispozici také"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Štítek"
 ],
 "Tags": [
  null,
  "Štítky"
 ],
 "Troubleshoot": [
  null,
  "Řešení problémů"
 ],
 "Type to filter…": [
  null,
  "Filtrujte psaním…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "V chodu od $0"
 ],
 "Used by": [
  null,
  "Používáno"
 ],
 "User": [
  null,
  "Uživatel"
 ],
 "User Podman service is also available": [
  null,
  "Uživatelská služba Podman je také k dispozici"
 ],
 "Value": [
  null,
  "Hodnota"
 ],
 "Volumes": [
  null,
  "Svazky"
 ],
 "With terminal": [
  null,
  "S terminálem"
 ],
 "configured": [
  null,
  "nastaveno"
 ],
 "container": [
  null,
  "kontejner"
 ],
 "created": [
  null,
  "vytvořeno"
 ],
 "exited": [
  null,
  "skončilo"
 ],
 "image": [
  null,
  "obraz"
 ],
 "in": [
  null,
  "v"
 ],
 "n/a": [
  null,
  "n/a"
 ],
 "not available": [
  null,
  "není k dispozici"
 ],
 "paused": [
  null,
  "pozastaveno"
 ],
 "pod group": [
  null,
  "skupina podu"
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "odebírání"
 ],
 "running": [
  null,
  "spuštěné"
 ],
 "select all": [
  null,
  "vybrat vše"
 ],
 "stopped": [
  null,
  "zastaveno"
 ],
 "system": [
  null,
  "systém"
 ]
});
