.container-section:not(.pod-card) {
    --pf-c-card--BoxShadow: none;
}
.container-section {
    margin-top: var(--pf-global--spacer--md);

    .pf-c-card__header {
        border-color: #ddd;
        padding-top: var(--pf-global--spacer--md);
    }

    .pf-c-card__body {
        padding: 0;
    }

    .pf-c-card__title {
        padding: 0;
        font-weight: var(--pf-global--FontWeight--normal);
        font-size: var(--pf-global--FontSize--sm);

        .pod-name {
            font-weight: var(--pf-global--FontWeight--bold);
            font-size: var(--pf-global--FontSize--md);
            padding-right: 1rem;
        }
    }

    .pf-c-card__header {
        padding-bottom: var(--pf-global--spacer-sm);
    }
}

.ct-table-empty td {
    padding: var(--pf-global--spacer--sm) var(--pf-global--spacer--md) var(--pf-global--spacer--lg);
}
