cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "sv",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Lägg till post"
 ],
 "Add on build variable": [
  null,
  "Lägg till byggvariabel"
 ],
 "All": [
  null,
  "Alla"
 ],
 "All registries": [
  null,
  "Alla register"
 ],
 "An error occured": [
  null,
  "Ett fel uppstod"
 ],
 "Author": [
  null,
  "Upphovsman"
 ],
 "Automatically start podman on boot": [
  null,
  "Kör igång podman automatiskt vid uppstart"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU delar"
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Checkpoint": [
  null,
  "Checkpunkt"
 ],
 "Checkpoint container $0": [
  null,
  "Ta checkpunkt på behållare $0"
 ],
 "Command": [
  null,
  "Kommando"
 ],
 "Commit": [
  null,
  "Fastställ"
 ],
 "Commit image": [
  null,
  "Fastställningsavbild"
 ],
 "Console": [
  null,
  "Konsol"
 ],
 "Container": [
  null,
  "Behållare"
 ],
 "Container failed to be created": [
  null,
  "Behållaren misslyckades att skapas"
 ],
 "Container failed to be started": [
  null,
  "Behållaren misslyckades att startas"
 ],
 "Container is currently running.": [
  null,
  "Behållaren kör för närvarande."
 ],
 "Container is not running": [
  null,
  "Behållaren kör inte"
 ],
 "Container name": [
  null,
  "Behållarnamn"
 ],
 "Container path": [
  null,
  "Behållarsökväg"
 ],
 "Container port": [
  null,
  "Behållarport"
 ],
 "Containers": [
  null,
  "Behållare"
 ],
 "Created": [
  null,
  "Skapad"
 ],
 "Delete": [
  null,
  "Radera"
 ],
 "Delete $0": [
  null,
  "Radera $0"
 ],
 "Delete image": [
  null,
  "Radera avbild"
 ],
 "Delete tagged images": [
  null,
  "Radera taggade avbilder"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "När en container raderas försvinner även all data i den."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Att ta bort denna kapsel kommer ta bort följande behållare:"
 ],
 "Details": [
  null,
  "Detaljer"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Inkludera inte rotfilsystemsändringar vid export"
 ],
 "Download": [
  null,
  "Ladda ner"
 ],
 "Entrypoint": [
  null,
  "Ingångspunkt"
 ],
 "Environment": [
  null,
  "Miljö"
 ],
 "Error": [
  null,
  "Fel"
 ],
 "Error message": [
  null,
  "Felmeddelande"
 ],
 "Error occured while connecting console": [
  null,
  "Ett fel uppstod vid anslutning till konsolen"
 ],
 "Exited": [
  null,
  "Avslutats"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Kunde inte ta checkpunkt av behållare $0"
 ],
 "Failed to commit container $0": [
  null,
  "Kunde inte fastställa behållaren $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Kunde inte ladda ner avbild $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Misslyckades att tvingande ta bort behållare $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Misslyckades att tvinga stopp av behållare $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Misslyckades att pausa kapseln $0"
 ],
 "Failed to remove container $0": [
  null,
  "Misslyckades att ta bort behållaren $0"
 ],
 "Failed to restart container $0": [
  null,
  "Misslyckades att starta om behållaren $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Misslyckades att starta om kapseln $0"
 ],
 "Failed to restore container $0": [
  null,
  "Misslyckades att återställa behållaren $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Misslyckades att återuppta kapseln $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Misslyckades att söka efter avbilder: $0"
 ],
 "Failed to search for new images": [
  null,
  "Misslyckades att söka efter nya avbilder"
 ],
 "Failed to start container $0": [
  null,
  "Misslyckades att starta behållaren $0"
 ],
 "Failed to start pod $0": [
  null,
  "Misslyckades att starta kapseln $0"
 ],
 "Failed to stop container $0": [
  null,
  "Misslyckades att stoppa behållaren $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Misslyckades att stoppa kapseln $0"
 ],
 "Force delete": [
  null,
  "Framtvinga borttagande"
 ],
 "Force restart": [
  null,
  "Framtvinga omstart"
 ],
 "Force stop": [
  null,
  "Framtvinga stopp"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Gateway": [
  null,
  "Gateway"
 ],
 "Get new image": [
  null,
  "Hämta ny avbild"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Dölj mellanliggande avbilder"
 ],
 "Host path": [
  null,
  "Värdsökväg"
 ],
 "Host port (optional)": [
  null,
  "Värdport (valfri)"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP (optional)": [
  null,
  "IP (valfri)"
 ],
 "IP address": [
  null,
  "IP-adress"
 ],
 "IP prefix length": [
  null,
  "IP-prefixlängd"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ignorera IP-adressen om den är statiskt satt"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ignorera MAC-adressen om den är statiskt satt"
 ],
 "Image": [
  null,
  "Avbild"
 ],
 "Image name": [
  null,
  "Avbildsnamn"
 ],
 "Images": [
  null,
  "Avbilder"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Behåll alla tillfälliga checkpunktsfiler"
 ],
 "Key": [
  null,
  "Nyckel"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Låt fortsätta köra efter att skriva checkpunkt till disk"
 ],
 "Loading logs...": [
  null,
  "Läser in loggar …"
 ],
 "Loading...": [
  null,
  "Läser in …"
 ],
 "Logs": [
  null,
  "Loggar"
 ],
 "MAC address": [
  null,
  "MAC-adress"
 ],
 "Memory": [
  null,
  "Minne"
 ],
 "Memory limit": [
  null,
  "Minnesgräns"
 ],
 "Message": [
  null,
  "Meddelande"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Flera taggar finns för denna avbild. Välj vilka taggade avbilder som skall raderas."
 ],
 "Name": [
  null,
  "Namn"
 ],
 "No SELinux label": [
  null,
  "Ingen SELinux-etikett"
 ],
 "No containers": [
  null,
  "Inga behållare"
 ],
 "No containers are using this image": [
  null,
  "Inga behållare använder denna avbild"
 ],
 "No containers in this pod": [
  null,
  "Inga behållare i denna kapsel"
 ],
 "No containers that match the current filter": [
  null,
  "Inga behållare som stämmer med det aktuella filtret"
 ],
 "No images": [
  null,
  "Inga avbilder"
 ],
 "No images found": [
  null,
  "Inga avbilder funna"
 ],
 "No images that match the current filter": [
  null,
  "Inga avbilder som stämmer med det aktuella filtret"
 ],
 "No results for $0": [
  null,
  "Inga resultat för $0"
 ],
 "No running containers": [
  null,
  "Inga körande behållare"
 ],
 "Only running": [
  null,
  "Endast körande"
 ],
 "Owner": [
  null,
  "Ägare"
 ],
 "Pause": [
  null,
  "Pausa"
 ],
 "Pause the container": [
  null,
  "Pausa behållaren"
 ],
 "Paused": [
  null,
  "Pausad"
 ],
 "Please confirm deletion of $0": [
  null,
  "Bekräfta att $0 skall tas bort"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Bekräfta att kapseln $0 skall tas bort"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Bekräfta att kapseln $0 skall raderas tvingande"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Bekräfta att $0 skall raderas tvingande"
 ],
 "Please retry another term.": [
  null,
  "Försök igen med en annan term."
 ],
 "Please start typing to look for images.": [
  null,
  "Börja skriva för att leta efter avbilder."
 ],
 "Podman containers": [
  null,
  "Podman-behållare"
 ],
 "Podman service is not active": [
  null,
  "Podman-tjänsten är inte aktiv"
 ],
 "Ports": [
  null,
  "Portar"
 ],
 "Private": [
  null,
  "Privat"
 ],
 "Pulling": [
  null,
  "Hämtar"
 ],
 "ReadOnly": [
  null,
  "LäsEndast"
 ],
 "ReadWrite": [
  null,
  "LäsSkriv"
 ],
 "Remove item": [
  null,
  "Ta bort post"
 ],
 "Remove on build variable": [
  null,
  "Ta bort byggvariabel"
 ],
 "Restart": [
  null,
  "Starta om"
 ],
 "Restore": [
  null,
  "Återställ"
 ],
 "Restore container $0": [
  null,
  "Återställ behållaren $0"
 ],
 "Restore with established TCP connections": [
  null,
  "Återställ med etablerade TCP-förbindelser"
 ],
 "Resume": [
  null,
  "Återuppta"
 ],
 "Run": [
  null,
  "Kör"
 ],
 "Run image": [
  null,
  "Kör avbild"
 ],
 "Running": [
  null,
  "Kör"
 ],
 "Search by name or description": [
  null,
  "Sök efter namn eller beskrivning"
 ],
 "Search for": [
  null,
  "Sök efter"
 ],
 "Search for an image": [
  null,
  "Sök efter en avbild"
 ],
 "Searching...": [
  null,
  "Söker …"
 ],
 "Set container on build variables": [
  null,
  "Sätt behållare på byggvariabler"
 ],
 "Shared": [
  null,
  "Delad"
 ],
 "Show": [
  null,
  "Visa"
 ],
 "Show intermediate images": [
  null,
  "Visa mellanliggande avbilder"
 ],
 "Size": [
  null,
  "Storlek"
 ],
 "Start": [
  null,
  "Starta"
 ],
 "Start podman": [
  null,
  "Starta podman"
 ],
 "State": [
  null,
  "Tillstånd"
 ],
 "Stop": [
  null,
  "Stoppa"
 ],
 "Stopped": [
  null,
  "Stoppad"
 ],
 "Support preserving established TCP connections": [
  null,
  "Stöd att bevara etablerade TCP-förbindelser"
 ],
 "System": [
  null,
  "System"
 ],
 "System Podman service is also available": [
  null,
  "System-podman-tjänsten är också tillgänglig"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Tagg"
 ],
 "Tags": [
  null,
  "Taggar"
 ],
 "Troubleshoot": [
  null,
  "Felsök"
 ],
 "Type to filter…": [
  null,
  "Skriv för att filtrera …"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Uppe sedan $0"
 ],
 "Used by": [
  null,
  "Används av"
 ],
 "User": [
  null,
  "Användare"
 ],
 "User Podman service is also available": [
  null,
  "Användar-podman-tjänsten är också tillgänglig"
 ],
 "Value": [
  null,
  "Värde"
 ],
 "Volumes": [
  null,
  "Volymer"
 ],
 "With terminal": [
  null,
  "Med terminal"
 ],
 "configured": [
  null,
  "konfigurerad"
 ],
 "container": [
  null,
  "behållare"
 ],
 "created": [
  null,
  "skapad"
 ],
 "exited": [
  null,
  "avslutad"
 ],
 "image": [
  null,
  "avbild"
 ],
 "in": [
  null,
  "i"
 ],
 "n/a": [
  null,
  "ej tillämpligt"
 ],
 "not available": [
  null,
  "inte tillgängligt"
 ],
 "paused": [
  null,
  "pausad"
 ],
 "pod group": [
  null,
  "kapselgrupp"
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "tar bort"
 ],
 "running": [
  null,
  "kör"
 ],
 "select all": [
  null,
  "välj alla"
 ],
 "stopped": [
  null,
  "stoppad"
 ],
 "system": [
  null,
  "system"
 ]
});
