cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "fr",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Ajouter un élément"
 ],
 "Add on build variable": [
  null,
  "Ajouter une variable de construction"
 ],
 "All": [
  null,
  "Tous"
 ],
 "All registries": [
  null,
  "Tous les registres"
 ],
 "An error occured": [
  null,
  "Une erreur s'est produite"
 ],
 "Author": [
  null,
  "Auteur"
 ],
 "Automatically start podman on boot": [
  null,
  "Démarrer automatiquement podman au démarrage"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "Parts de CPU"
 ],
 "Cancel": [
  null,
  "Annuler"
 ],
 "Checkpoint": [
  null,
  "Point de contrôle"
 ],
 "Checkpoint container $0": [
  null,
  "Point de contrôle du conteneur $0"
 ],
 "Command": [
  null,
  "Commande"
 ],
 "Commit": [
  null,
  "Valider"
 ],
 "Commit image": [
  null,
  "Valider image"
 ],
 "Console": [
  null,
  "Console"
 ],
 "Container": [
  null,
  "Conteneur"
 ],
 "Container failed to be created": [
  null,
  "Le conteneur n’a pas pu être créé"
 ],
 "Container failed to be started": [
  null,
  "Le conteneur n’a pas pu être démarré"
 ],
 "Container is currently running.": [
  null,
  "Le conteneur est actuellement en cours d’exécution."
 ],
 "Container is not running": [
  null,
  "Le conteneur n’est pas en cours d’exécution"
 ],
 "Container name": [
  null,
  "Nom du conteneur"
 ],
 "Container path": [
  null,
  "Chemin du conteneur"
 ],
 "Container port": [
  null,
  "Port du conteneur"
 ],
 "Containers": [
  null,
  "Conteneurs"
 ],
 "Created": [
  null,
  "Créé"
 ],
 "Delete": [
  null,
  "Supprimer"
 ],
 "Delete $0": [
  null,
  "Supprimer $0"
 ],
 "Delete image": [
  null,
  "Supprimer l'image"
 ],
 "Delete tagged images": [
  null,
  "Supprimer les images taguées"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Supprimer un conteneur va effacer toutes les données qu’il contient."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "La suppression de ce pod entraînera celle des conteneurs suivants :"
 ],
 "Details": [
  null,
  "Détails"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Ne pas inclure les changements effectués sur la racine du système de fichier lors de l'export"
 ],
 "Download": [
  null,
  "Télécharger"
 ],
 "Entrypoint": [
  null,
  "Point d’entrée"
 ],
 "Environment": [
  null,
  "Environnement"
 ],
 "Error": [
  null,
  "Erreur"
 ],
 "Error message": [
  null,
  "Message d’erreur"
 ],
 "Error occured while connecting console": [
  null,
  "Une erreur s'est produite lors de la connection à la console"
 ],
 "Exited": [
  null,
  "Quittés"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Échec de la création du point de contrôle du conteneur $0"
 ],
 "Failed to commit container $0": [
  null,
  "Échec de la validation du conteneur $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Échec du téléchargement de l’image $0 : $1"
 ],
 "Failed to force remove container $0": [
  null,
  "Échec de la suppression forcée du conteneur $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Échec de l'arrêt forcé du pod $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Échec de la mise en pause du pod $0"
 ],
 "Failed to remove container $0": [
  null,
  "Échec de la suppression du conteneur $0"
 ],
 "Failed to restart container $0": [
  null,
  "Échec du redémarrage du conteneur $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Échec du redémarrage du pod $0"
 ],
 "Failed to restore container $0": [
  null,
  "Échec de la restauration du conteneur $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Échec de la reprise du pod $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Échec de la recherche de l'image : $0"
 ],
 "Failed to search for new images": [
  null,
  "Échec de la recherche de nouvelles images"
 ],
 "Failed to start container $0": [
  null,
  "Échec du démarrage du conteneur $0"
 ],
 "Failed to start pod $0": [
  null,
  "Échec du démarrage du pod $0"
 ],
 "Failed to stop container $0": [
  null,
  "Échec de l’arrêt du conteneur $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Échec de l’arrêt du pod $0"
 ],
 "Force delete": [
  null,
  "Suppression forcée"
 ],
 "Force restart": [
  null,
  "Redémarrage forcé"
 ],
 "Force stop": [
  null,
  "Arrêt forcé"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Gateway": [
  null,
  "Passerelle"
 ],
 "Get new image": [
  null,
  "Obtenir une nouvelle image"
 ],
 "GiB": [
  null,
  "Gio"
 ],
 "Hide intermediate images": [
  null,
  "Cacher les images intermédiaires"
 ],
 "Host path": [
  null,
  "Chemin vers l’hôte"
 ],
 "Host port (optional)": [
  null,
  "Port de l’hôte (optionnel)"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP (optional)": [
  null,
  "IP (optionnel)"
 ],
 "IP address": [
  null,
  "Adresse IP"
 ],
 "IP prefix length": [
  null,
  "Taille du préfixe IP"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ignorer l'adresse IP si définie statiquement"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ignorer l'adresse MAC si définie statiquement"
 ],
 "Image": [
  null,
  "Image"
 ],
 "Image name": [
  null,
  "Nom de l’image"
 ],
 "Images": [
  null,
  "Images"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Conserver tous les fichiers de points de contrôle temporaires"
 ],
 "Key": [
  null,
  "Clé"
 ],
 "KiB": [
  null,
  "Kio"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Conserver actif après la création du point de contrôle sur le disque"
 ],
 "Loading logs...": [
  null,
  "Chargement des logs…"
 ],
 "Loading...": [
  null,
  "Chargement…"
 ],
 "Logs": [
  null,
  "Journaux"
 ],
 "MAC address": [
  null,
  "Adresse MAC"
 ],
 "Memory": [
  null,
  "Mémoire"
 ],
 "Memory limit": [
  null,
  "Limite mémoire"
 ],
 "Message": [
  null,
  "Message"
 ],
 "MiB": [
  null,
  "Mio"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Plusieurs tags existent pour cette image. Sélectionnez les images marquées à supprimer."
 ],
 "Name": [
  null,
  "Nom"
 ],
 "No SELinux label": [
  null,
  "Pas de label SELinux"
 ],
 "No containers": [
  null,
  "Aucun conteneur"
 ],
 "No containers are using this image": [
  null,
  "Aucun conteneur n’utilise cette image"
 ],
 "No containers in this pod": [
  null,
  "Aucun conteneur dans ce pod"
 ],
 "No containers that match the current filter": [
  null,
  "Aucun conteneur ne correspond au filtre actuel"
 ],
 "No images": [
  null,
  "Aucune image"
 ],
 "No images found": [
  null,
  "Aucune image trouvée"
 ],
 "No images that match the current filter": [
  null,
  "Aucune image ne correspond au filtre actuel"
 ],
 "No results for $0": [
  null,
  "Aucun résultat pour $0"
 ],
 "No running containers": [
  null,
  "Aucun conteneur en cours d’exécution"
 ],
 "Only running": [
  null,
  "En cours d’exécution seulement"
 ],
 "Owner": [
  null,
  "Propriétaire"
 ],
 "Pause": [
  null,
  "Pause"
 ],
 "Pause the container": [
  null,
  "Mettre le conteneur en pause"
 ],
 "Paused": [
  null,
  "En pause"
 ],
 "Please confirm deletion of $0": [
  null,
  "Veuillez confirmer la suppression de $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Veuillez confirmer la suppression du pod $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Veuillez confirmer la suppression forcée du pod $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Veuillez confirmer la suppression forcée de $0"
 ],
 "Please retry another term.": [
  null,
  "Veuillez essayer avec un autre terme."
 ],
 "Please start typing to look for images.": [
  null,
  "Commencez à écrire pour chercher une image."
 ],
 "Podman containers": [
  null,
  "Conteneurs Podman"
 ],
 "Podman service is not active": [
  null,
  "Le service Podman n’est pas actif"
 ],
 "Ports": [
  null,
  "Ports"
 ],
 "Private": [
  null,
  "Privé"
 ],
 "Pulling": [
  null,
  "Tirage"
 ],
 "ReadOnly": [
  null,
  "LectureSeule"
 ],
 "ReadWrite": [
  null,
  "LectureÉcriture"
 ],
 "Remove item": [
  null,
  "Supprimer l'élément"
 ],
 "Remove on build variable": [
  null,
  "Supprimer la variable de construction"
 ],
 "Restart": [
  null,
  "Redémarrer"
 ],
 "Restore": [
  null,
  "Restaurer"
 ],
 "Restore container $0": [
  null,
  "Restaurer le conteneur $0"
 ],
 "Restore with established TCP connections": [
  null,
  "Restaurer avec les connexions TCP établies"
 ],
 "Resume": [
  null,
  "Reprendre"
 ],
 "Run": [
  null,
  "Exécuter"
 ],
 "Run image": [
  null,
  "Exécuter l'image"
 ],
 "Running": [
  null,
  "En fonctionnement"
 ],
 "Search by name or description": [
  null,
  "Rechercher par nom ou description"
 ],
 "Search for": [
  null,
  "Rechercher"
 ],
 "Search for an image": [
  null,
  "Chercher une image"
 ],
 "Searching...": [
  null,
  "Recherche en cours…"
 ],
 "Set container on build variables": [
  null,
  "Définir le conteneur sur les variables de construction"
 ],
 "Shared": [
  null,
  "Partagé"
 ],
 "Show": [
  null,
  "Afficher"
 ],
 "Show intermediate images": [
  null,
  "Afficher les images intermédiaires"
 ],
 "Size": [
  null,
  "Taille"
 ],
 "Start": [
  null,
  "Démarrer"
 ],
 "Start podman": [
  null,
  "Démarrer podman"
 ],
 "State": [
  null,
  "État"
 ],
 "Stop": [
  null,
  "Arrêter"
 ],
 "Stopped": [
  null,
  "Arrêté"
 ],
 "Support preserving established TCP connections": [
  null,
  "Prendre en charge le maintien des connexions TCP établies"
 ],
 "System": [
  null,
  "Système"
 ],
 "System Podman service is also available": [
  null,
  "Le service Podman est également disponible"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Tag"
 ],
 "Tags": [
  null,
  "Étiquettes"
 ],
 "Troubleshoot": [
  null,
  "Dépannage"
 ],
 "Type to filter…": [
  null,
  "Entrez pour filtrer…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "En cours d’exécution depuis $0"
 ],
 "Used by": [
  null,
  "Utilisé par"
 ],
 "User": [
  null,
  "Utilisateur"
 ],
 "User Podman service is also available": [
  null,
  "Le service utilisateur Podman est également disponible"
 ],
 "Value": [
  null,
  "Valeur"
 ],
 "Volumes": [
  null,
  "Volumes"
 ],
 "With terminal": [
  null,
  "Avec le terminal"
 ],
 "configured": [
  null,
  "configuré"
 ],
 "container": [
  null,
  "conteneur"
 ],
 "created": [
  null,
  "créé"
 ],
 "exited": [
  null,
  "Quittés"
 ],
 "image": [
  null,
  "image"
 ],
 "in": [
  null,
  "dans"
 ],
 "n/a": [
  null,
  "n. d."
 ],
 "not available": [
  null,
  "non disponible"
 ],
 "paused": [
  null,
  "Mis en pause"
 ],
 "pod group": [
  null,
  "groupe de pod"
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "en cours de suppression"
 ],
 "running": [
  null,
  "en cours d'exécution"
 ],
 "select all": [
  null,
  "tout sélectionner"
 ],
 "stopped": [
  null,
  "arrêté"
 ],
 "system": [
  null,
  "système"
 ]
});
