cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "tr",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Öğe ekle"
 ],
 "Add on build variable": [
  null,
  "Yapım değişkeninde ekle"
 ],
 "All": [
  null,
  "Tümü"
 ],
 "All registries": [
  null,
  "Tüm kayıtlar"
 ],
 "An error occured": [
  null,
  "Bir hata meydana geldi"
 ],
 "Author": [
  null,
  "Hazırlayan"
 ],
 "Automatically start podman on boot": [
  null,
  "Podman'ı önyüklemede otomatik olarak başlat"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU paylaşımları"
 ],
 "Cancel": [
  null,
  "İptal"
 ],
 "Checkpoint": [
  null,
  "Denetim noktası"
 ],
 "Checkpoint container $0": [
  null,
  "$0 konteyneri için denetim noktası"
 ],
 "Command": [
  null,
  "Komut"
 ],
 "Commit": [
  null,
  "İşle"
 ],
 "Commit image": [
  null,
  "Kalıbı işle"
 ],
 "Console": [
  null,
  "Konsol"
 ],
 "Container": [
  null,
  "Konteyner"
 ],
 "Container failed to be created": [
  null,
  "Konteyner oluşturulamadı"
 ],
 "Container failed to be started": [
  null,
  "Konteyner başlatılamadı"
 ],
 "Container is currently running.": [
  null,
  "Konteyner şu anda çalışıyor."
 ],
 "Container is not running": [
  null,
  "Konteyner çalışmıyor"
 ],
 "Container name": [
  null,
  "Konteyner Adı"
 ],
 "Container path": [
  null,
  "Konteyner konumu"
 ],
 "Container port": [
  null,
  "Konteyner bağlantı noktası"
 ],
 "Containers": [
  null,
  "Konteynerler"
 ],
 "Created": [
  null,
  "Oluşturuldu"
 ],
 "Delete": [
  null,
  "Sil"
 ],
 "Delete $0": [
  null,
  "$0 sil"
 ],
 "Delete image": [
  null,
  "Kalıp sil"
 ],
 "Delete tagged images": [
  null,
  "Etiketli kalıpları sil"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Bir konteyneri silmek içindeki tüm verileri silecektir."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Bu bölmeyi silmek aşağıdaki konteynerleri kaldıracaktır:"
 ],
 "Details": [
  null,
  "Ayrıntılar"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Dışa aktarırken kök dosya sistemi değişikliklerini dahil etme"
 ],
 "Download": [
  null,
  "İndir"
 ],
 "Entrypoint": [
  null,
  "Giriş noktası"
 ],
 "Environment": [
  null,
  "Ortam"
 ],
 "Error": [
  null,
  "Hata"
 ],
 "Error message": [
  null,
  "Hata iletisi"
 ],
 "Error occured while connecting console": [
  null,
  "Konsola bağlanırken hata meydana geldi"
 ],
 "Exited": [
  null,
  "Çıkış yaptı"
 ],
 "Failed to checkpoint container $0": [
  null,
  "$0 konteyneri için denetim noktası oluşturulamadı"
 ],
 "Failed to commit container $0": [
  null,
  "$0 konteyneri işlenemedi"
 ],
 "Failed to download image $0:$1": [
  null,
  "$0:$1 kalıbı indirilemedi"
 ],
 "Failed to force remove container $0": [
  null,
  "$0 konteyneri zorla kaldırılamadı"
 ],
 "Failed to force stop pod $0": [
  null,
  "$0 bölmesi zorla durdurulamadı"
 ],
 "Failed to pause pod $0": [
  null,
  "$0 bölmesi duraklatılamadı"
 ],
 "Failed to remove container $0": [
  null,
  "$0 konteyneri kaldırılamadı"
 ],
 "Failed to restart container $0": [
  null,
  "$0 konteyneri yeniden başlatılamadı"
 ],
 "Failed to restart pod $0": [
  null,
  "$0 bölmesi yeniden başlatılamadı"
 ],
 "Failed to restore container $0": [
  null,
  "$0 konteyneri geri yüklenemedi"
 ],
 "Failed to resume pod $0": [
  null,
  "$0 bölmesi sürdürülemedi"
 ],
 "Failed to search for images: $0": [
  null,
  "Kalıplar aranamadı: $0"
 ],
 "Failed to search for new images": [
  null,
  "Yeni kalıplar aranamadı"
 ],
 "Failed to start container $0": [
  null,
  "$0 konteyneri başlatılamadı"
 ],
 "Failed to start pod $0": [
  null,
  "$0 bölmesi başlatılamadı"
 ],
 "Failed to stop container $0": [
  null,
  "$0 konteyneri durdurulamadı"
 ],
 "Failed to stop pod $0": [
  null,
  "$0 bölmesi durdurulamadı"
 ],
 "Force delete": [
  null,
  "Silmeye zorla"
 ],
 "Force restart": [
  null,
  "Yeniden başlatmaya zorla"
 ],
 "Force stop": [
  null,
  "Durdurmaya zorla"
 ],
 "Format": [
  null,
  "Biçim"
 ],
 "Gateway": [
  null,
  "Ağ geçidi"
 ],
 "Get new image": [
  null,
  "Yeni kalıp al"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Ara kalıpları gizle"
 ],
 "Host path": [
  null,
  "Anamakine yolu"
 ],
 "Host port (optional)": [
  null,
  "Anamakine bağlantı noktası (isteğe bağlı)"
 ],
 "ID": [
  null,
  "Kimlik"
 ],
 "IP (optional)": [
  null,
  "IP (isteğe bağlı)"
 ],
 "IP address": [
  null,
  "IP adresi"
 ],
 "IP prefix length": [
  null,
  "IP ön ek uzunluğu"
 ],
 "Ignore IP address if set statically": [
  null,
  "Sabit olarak ayarlanmışsa IP adresini yoksay"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Sabit olarak ayarlanmışsa MAC adresini yoksay"
 ],
 "Image": [
  null,
  "Kalıp"
 ],
 "Image name": [
  null,
  "Kalıp adı"
 ],
 "Images": [
  null,
  "Kalıplar"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Tüm geçici denetim noktası dosyalarını sakla"
 ],
 "Key": [
  null,
  "Anahtar"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Denetim noktasını diske yazdıktan sonra çalışır durumda bırak"
 ],
 "Loading logs...": [
  null,
  "Günlükler yükleniyor..."
 ],
 "Loading...": [
  null,
  "Yükleniyor..."
 ],
 "Logs": [
  null,
  "Günlükler"
 ],
 "MAC address": [
  null,
  "MAC adresi"
 ],
 "Memory": [
  null,
  "Bellek"
 ],
 "Memory limit": [
  null,
  "Bellek sınırı"
 ],
 "Message": [
  null,
  "İleti"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Bu kalıp için birden fazla etiket var. Silinecek etiketlenmiş kalıpları seçin."
 ],
 "Name": [
  null,
  "Ad"
 ],
 "No SELinux label": [
  null,
  "SELinux etiketi yok"
 ],
 "No containers": [
  null,
  "Konteynerler yok"
 ],
 "No containers are using this image": [
  null,
  "Bu kalıbı hiçbir konteyner kullanmıyor"
 ],
 "No containers in this pod": [
  null,
  "Bu bölmede konteynerler yok"
 ],
 "No containers that match the current filter": [
  null,
  "Şu anki süzgeçle eşleşen konteynerler yok"
 ],
 "No images": [
  null,
  "Kalıplar yok"
 ],
 "No images found": [
  null,
  "Bulunan kalıplar yok"
 ],
 "No images that match the current filter": [
  null,
  "Şu anki süzgeçle eşleşen kalıplar yok"
 ],
 "No results for $0": [
  null,
  "$0 için sonuçlar yok"
 ],
 "No running containers": [
  null,
  "Çalışan konteyner yok"
 ],
 "Only running": [
  null,
  "Sadece çalışanlar"
 ],
 "Owner": [
  null,
  "Sahibi"
 ],
 "Pause": [
  null,
  "Duraklat"
 ],
 "Pause the container": [
  null,
  "Konteyneri duraklat"
 ],
 "Paused": [
  null,
  "Duraklatıldı"
 ],
 "Please confirm deletion of $0": [
  null,
  "Lütfen $0 için silme işlemini onaylayın"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Lütfen $0 bölmesinin silme işlemini onaylayın"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Lütfen $0 bölmesinin zorla silme işlemini onaylayın"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Lütfen $0 için zorla silme işlemini onaylayın"
 ],
 "Please retry another term.": [
  null,
  "Lütfen başka bir terim ile yeniden deneyin."
 ],
 "Please start typing to look for images.": [
  null,
  "Lütfen kalıpları aramak için yazmaya başlayın."
 ],
 "Podman containers": [
  null,
  "Podman konteynerleri"
 ],
 "Podman service is not active": [
  null,
  "Podman hizmeti etkin değil"
 ],
 "Ports": [
  null,
  "Bağlantı Noktaları"
 ],
 "Private": [
  null,
  "Özel"
 ],
 "Pulling": [
  null,
  "Çekiliyor"
 ],
 "ReadOnly": [
  null,
  "SadeceOku"
 ],
 "ReadWrite": [
  null,
  "OkuYaz"
 ],
 "Remove item": [
  null,
  "Öge kaldır"
 ],
 "Remove on build variable": [
  null,
  "Yapım değişkeninde kaldır"
 ],
 "Restart": [
  null,
  "Yeniden başlat"
 ],
 "Restore": [
  null,
  "Geri yükle"
 ],
 "Restore container $0": [
  null,
  "$0 konteynerini geri yükle"
 ],
 "Restore with established TCP connections": [
  null,
  "Kurulu TCP bağlantıları ile geri yükle"
 ],
 "Resume": [
  null,
  "Sürdür"
 ],
 "Run": [
  null,
  "Çalıştır"
 ],
 "Run image": [
  null,
  "Kalıbı çalıştır"
 ],
 "Running": [
  null,
  "Çalışıyor"
 ],
 "Search by name or description": [
  null,
  "İsme veya açıklamaya göre ara"
 ],
 "Search for": [
  null,
  "Ara"
 ],
 "Search for an image": [
  null,
  "Kalıp ara"
 ],
 "Searching...": [
  null,
  "Aranıyor..."
 ],
 "Set container on build variables": [
  null,
  "Yapım değişkenlerinde konteyneri ayarla"
 ],
 "Shared": [
  null,
  "Paylaşılan"
 ],
 "Show": [
  null,
  "Göster"
 ],
 "Show intermediate images": [
  null,
  "Ara kalıpları göster"
 ],
 "Size": [
  null,
  "Boyut"
 ],
 "Start": [
  null,
  "Başlat"
 ],
 "Start podman": [
  null,
  "Podman'ı başlat"
 ],
 "State": [
  null,
  "Durum"
 ],
 "Stop": [
  null,
  "Durdur"
 ],
 "Stopped": [
  null,
  "Durduruldu"
 ],
 "Support preserving established TCP connections": [
  null,
  "Kurulu TCP bağlantılarını korumayı destekle"
 ],
 "System": [
  null,
  "Sistem"
 ],
 "System Podman service is also available": [
  null,
  "Sistem Podman hizmeti de kullanılabilir"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiket"
 ],
 "Tags": [
  null,
  "Etiketler"
 ],
 "Troubleshoot": [
  null,
  "Sorun Giderme"
 ],
 "Type to filter…": [
  null,
  "Filtrelemek için yazın…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "$0'dan beri aktif"
 ],
 "Used by": [
  null,
  "Kullanan"
 ],
 "User": [
  null,
  "Kullanıcı"
 ],
 "User Podman service is also available": [
  null,
  "Kullanıcı Podman hizmeti de kullanılabilir"
 ],
 "Value": [
  null,
  "Değer"
 ],
 "Volumes": [
  null,
  "Bölümler"
 ],
 "With terminal": [
  null,
  "Terminal ile"
 ],
 "configured": [
  null,
  "yapılandırıldı"
 ],
 "container": [
  null,
  "konteyner"
 ],
 "created": [
  null,
  "oluşturuldu"
 ],
 "exited": [
  null,
  "çıkış yaptı"
 ],
 "image": [
  null,
  "kalıp"
 ],
 "in": [
  null,
  "şurada"
 ],
 "n/a": [
  null,
  "yok"
 ],
 "not available": [
  null,
  "kullanılabilir değil"
 ],
 "paused": [
  null,
  "duraklatıldı"
 ],
 "pod group": [
  null,
  "bölme grubu"
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "kaldırılıyor"
 ],
 "running": [
  null,
  "çalışıyor"
 ],
 "select all": [
  null,
  "tümünü seç"
 ],
 "stopped": [
  null,
  "durduruldu"
 ],
 "system": [
  null,
  "sistem"
 ]
});
