cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "pt_BR",
  "x-generator": "Weblate 4.2.1"
 },
 "Add item": [
  null,
  "Adicionar Item"
 ],
 "Add on build variable": [
  null,
  "Adicionar variável de construção"
 ],
 "All": [
  null,
  "Todos"
 ],
 "All registries": [
  null,
  "Todos os registros"
 ],
 "An error occured": [
  null,
  "Um erro ocorreu"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Iniciar podman automaticamente na inicialização"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "Divisão de CPU"
 ],
 "Cancel": [
  null,
  "Cancelar"
 ],
 "Checkpoint": [
  null,
  ""
 ],
 "Command": [
  null,
  "Comando"
 ],
 "Commit": [
  null,
  "Commit"
 ],
 "Commit image": [
  null,
  "Efetivar imagem"
 ],
 "Console": [
  null,
  "Console"
 ],
 "Container failed to be created": [
  null,
  "Criação do contêiner falhou"
 ],
 "Container is currently running.": [
  null,
  "Contêiner está em execução."
 ],
 "Container is not running": [
  null,
  "Contêiner não está em execução"
 ],
 "Container name": [
  null,
  "Nome do contêiner"
 ],
 "Container path": [
  null,
  "Caminho do contêiner"
 ],
 "Container port": [
  null,
  "Porta do contêiner"
 ],
 "Containers": [
  null,
  "Contêineres"
 ],
 "Created": [
  null,
  "Criado"
 ],
 "Delete": [
  null,
  "Excluir"
 ],
 "Delete $0": [
  null,
  "Excluir $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Excluir um contêiner irá apagar todos os dados que ele contém."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  ""
 ],
 "Details": [
  null,
  "Detalhes"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  ""
 ],
 "Download": [
  null,
  "Baixar"
 ],
 "Entrypoint": [
  null,
  "Ponto de entrada"
 ],
 "Environment": [
  null,
  "Ambiente"
 ],
 "Error": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Mensagem de erro"
 ],
 "Error occured while connecting console": [
  null,
  ""
 ],
 "Exited": [
  null,
  "Saiu"
 ],
 "Failed to commit container $0": [
  null,
  "Falha ao efetivar contêiner $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Falha em baixar imagem $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Falha ao forçar remoção do contêiner $0"
 ],
 "Failed to remove container $0": [
  null,
  "Falha ao remover contêiner $0"
 ],
 "Failed to restart container $0": [
  null,
  "Falha ao reiniciar contêiner $0"
 ],
 "Failed to search for new images": [
  null,
  "Falha ao pesquisar por novas imagens"
 ],
 "Failed to start container $0": [
  null,
  "Falha ao iniciar contêiner $0"
 ],
 "Failed to stop container $0": [
  null,
  "Falha ao parar o contêiner $0"
 ],
 "Force delete": [
  null,
  "Forçar remoção"
 ],
 "Force restart": [
  null,
  "Forçar reinício"
 ],
 "Force stop": [
  null,
  "Forçar parada"
 ],
 "Format": [
  null,
  "Formato"
 ],
 "Gateway": [
  null,
  ""
 ],
 "Get new image": [
  null,
  "Obter nova imagem"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  ""
 ],
 "Host path": [
  null,
  "Caminho do host"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP (optional)": [
  null,
  ""
 ],
 "IP address": [
  null,
  ""
 ],
 "IP prefix length": [
  null,
  ""
 ],
 "Ignore IP address if set statically": [
  null,
  ""
 ],
 "Ignore MAC address if set statically": [
  null,
  ""
 ],
 "Image": [
  null,
  "Imagem"
 ],
 "Image name": [
  null,
  "Nome da imagem"
 ],
 "Images": [
  null,
  "Imagens"
 ],
 "Keep all temporary checkpoint files": [
  null,
  ""
 ],
 "Key": [
  null,
  "Chave"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading...": [
  null,
  "Carregando..."
 ],
 "Logs": [
  null,
  ""
 ],
 "MAC address": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Memória"
 ],
 "Memory limit": [
  null,
  "Limite de memória"
 ],
 "Message": [
  null,
  "Mensagem"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "Nome"
 ],
 "No SELinux label": [
  null,
  ""
 ],
 "No containers": [
  null,
  "Nenhum contêineres"
 ],
 "No containers are using this image": [
  null,
  "Nenhum contêiner está usando está imagem"
 ],
 "No containers that match the current filter": [
  null,
  "Nenhum contêiner correspondente ao filtro atual"
 ],
 "No images": [
  null,
  "Nenhuma imagem"
 ],
 "No images that match the current filter": [
  null,
  "Nenhuma imagem correspondente ao filtro atual"
 ],
 "No results for $0": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Nenhum contêiner em execução"
 ],
 "Only running": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Proprietário"
 ],
 "Pause": [
  null,
  "Pausar"
 ],
 "Pause the container": [
  null,
  "Pausar o contêiner"
 ],
 "Please confirm deletion of $0": [
  null,
  "Por favor confirme a remoção de $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Por favor confirme a remoção forçada de $0"
 ],
 "Please start typing to look for images.": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Contêineres podman"
 ],
 "Podman service is not active": [
  null,
  "Serviço podman não está ativo"
 ],
 "Ports": [
  null,
  "Portas"
 ],
 "Private": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "Obtendo"
 ],
 "ReadOnly": [
  null,
  "Somente-leitura"
 ],
 "ReadWrite": [
  null,
  "Leitura/Gravação"
 ],
 "Remove item": [
  null,
  ""
 ],
 "Restart": [
  null,
  "Reiniciar"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Executar"
 ],
 "Run image": [
  null,
  "Executar imagem"
 ],
 "Running": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  "Procurar por nome ou descrição"
 ],
 "Set container on build variables": [
  null,
  "Definir contêiner nas variáveis de construção"
 ],
 "Show": [
  null,
  ""
 ],
 "Show intermediate images": [
  null,
  ""
 ],
 "Size": [
  null,
  "Tamanho"
 ],
 "Start": [
  null,
  "Iniciar"
 ],
 "Start podman": [
  null,
  "Iniciar podman"
 ],
 "State": [
  null,
  "Estado"
 ],
 "Stop": [
  null,
  "Parar"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "Sistema"
 ],
 "System Podman service is also available": [
  null,
  ""
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiqueta"
 ],
 "Tags": [
  null,
  "Etiquetas"
 ],
 "Type to filter…": [
  null,
  ""
 ],
 "User": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  ""
 ],
 "Value": [
  null,
  ""
 ],
 "configured": [
  null,
  ""
 ],
 "in": [
  null,
  ""
 ],
 "pod group": [
  null,
  ""
 ],
 "removing": [
  null,
  ""
 ],
 "running": [
  null,
  ""
 ],
 "select all": [
  null,
  ""
 ],
 "stopped": [
  null,
  ""
 ]
});
