cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;
return plural;
},
  "language": "pl",
  "x-generator": "Weblate 4.3.2"
 },
 "Add item": [
  null,
  "Dodaj element"
 ],
 "Add on build variable": [
  null,
  "Dodaj na zmiennej budowania"
 ],
 "All": [
  null,
  "Wszystko"
 ],
 "All registries": [
  null,
  "Wszystkie rejestry"
 ],
 "An error occured": [
  null,
  "Wystąpił błąd"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Automatyczne włączanie usługi podman podczas uruchamiania"
 ],
 "CPU": [
  null,
  "Procesor"
 ],
 "CPU shares": [
  null,
  "Udziały procesora"
 ],
 "Cancel": [
  null,
  "Anuluj"
 ],
 "Checkpoint": [
  null,
  "Punkt kontrolny"
 ],
 "Checkpoint container $0": [
  null,
  "Kontener punktu kontrolnego $0"
 ],
 "Command": [
  null,
  "Polecenie"
 ],
 "Commit": [
  null,
  "Zatwierdź"
 ],
 "Commit image": [
  null,
  "Zatwierdź obraz"
 ],
 "Console": [
  null,
  "Konsola"
 ],
 "Container": [
  null,
  "Kontener"
 ],
 "Container failed to be created": [
  null,
  "Utworzenie kontenera się nie powiodło"
 ],
 "Container failed to be started": [
  null,
  "Uruchomienie kontenera się nie powiodło"
 ],
 "Container is currently running.": [
  null,
  "Kontener jest obecnie uruchomiony."
 ],
 "Container is not running": [
  null,
  "Kontener nie jest uruchomiony"
 ],
 "Container name": [
  null,
  "Nazwa kontenera"
 ],
 "Container path": [
  null,
  "Ścieżka do kontenera"
 ],
 "Container port": [
  null,
  "Port kontenera"
 ],
 "Containers": [
  null,
  "Kontenery"
 ],
 "Created": [
  null,
  "Utworzono"
 ],
 "Delete": [
  null,
  "Usuń"
 ],
 "Delete $0": [
  null,
  "Usuń $0"
 ],
 "Delete image": [
  null,
  "Usuń obraz"
 ],
 "Delete tagged images": [
  null,
  "Usuń oznaczone obrazy"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Usunięcie kontenera spowoduje usunięcie wszystkich zawartych na nim danych."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "Usunięcie tego pojemnika spowoduje usunięcie tych kontenerów:"
 ],
 "Details": [
  null,
  "Szczegóły"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "Bez dołączania zmian głównego systemu plików podczas eksportowania"
 ],
 "Download": [
  null,
  "Pobierz"
 ],
 "Entrypoint": [
  null,
  "Punkt wejścia"
 ],
 "Environment": [
  null,
  "Środowisko"
 ],
 "Error": [
  null,
  "Błąd"
 ],
 "Error message": [
  null,
  "Komunikat o błędzie"
 ],
 "Error occured while connecting console": [
  null,
  "Wystąpił błąd podczas łączenia konsoli"
 ],
 "Exited": [
  null,
  "Zakończono"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Punkt kontrolny kontenera $0 się nie powiódł"
 ],
 "Failed to commit container $0": [
  null,
  "Zatwierdzenie kontenera $0 się nie powiodło"
 ],
 "Failed to download image $0:$1": [
  null,
  "Pobranie obrazu $0:$1 się nie powiodło"
 ],
 "Failed to force remove container $0": [
  null,
  "Wymuszenie usunięcia kontenera $0 się nie powiodło"
 ],
 "Failed to force stop pod $0": [
  null,
  "Wymuszenie zatrzymania pojemnika $0 się nie powiodło"
 ],
 "Failed to pause pod $0": [
  null,
  "Wstrzymanie pojemnika $0 się nie powiodło"
 ],
 "Failed to remove container $0": [
  null,
  "Usunięcie kontenera $0 się nie powiodło"
 ],
 "Failed to restart container $0": [
  null,
  "Ponowne uruchomienie kontenera $0 się nie powiodło"
 ],
 "Failed to restart pod $0": [
  null,
  "Ponowne uruchomienie pojemnika $0 się nie powiodło"
 ],
 "Failed to restore container $0": [
  null,
  "Przywrócenie kontenera $0 się nie powiodło"
 ],
 "Failed to resume pod $0": [
  null,
  "Wznowienie pojemnika $0 się nie powiodło"
 ],
 "Failed to search for images: $0": [
  null,
  "Wyszukanie obrazów się nie powiodło: $0"
 ],
 "Failed to search for new images": [
  null,
  "Wyszukanie nowych obrazów się nie powiodło"
 ],
 "Failed to start container $0": [
  null,
  "Uruchomienie kontenera $0 się nie powiodło"
 ],
 "Failed to start pod $0": [
  null,
  "Uruchomienie pojemnika $0 się nie powiodło"
 ],
 "Failed to stop container $0": [
  null,
  "Zatrzymanie kontenera $0 się nie powiodło"
 ],
 "Failed to stop pod $0": [
  null,
  "Zatrzymanie pojemnika $0 się nie powiodło"
 ],
 "Force delete": [
  null,
  "Wymuś usunięcie"
 ],
 "Force restart": [
  null,
  "Wymuś ponowne uruchomienie"
 ],
 "Force stop": [
  null,
  "Wymuś zatrzymanie"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Gateway": [
  null,
  "Brama"
 ],
 "Get new image": [
  null,
  "Pobierz nowy obraz"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "Ukryj pośrednie obrazy"
 ],
 "Host path": [
  null,
  "Ścieżka do gospodarza"
 ],
 "Host port (optional)": [
  null,
  "Port gospodarza (opcjonalnie)"
 ],
 "ID": [
  null,
  "Identyfikator"
 ],
 "IP (optional)": [
  null,
  "IP (opcjonalnie)"
 ],
 "IP address": [
  null,
  "Adres IP"
 ],
 "IP prefix length": [
  null,
  "Długość przedrostka IP"
 ],
 "Ignore IP address if set statically": [
  null,
  "Ignorowanie adresu IP, jeśli jest ustawiony statycznie"
 ],
 "Ignore MAC address if set statically": [
  null,
  "Ignorowanie adresu MAC, jeśli jest ustawiony statycznie"
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image name": [
  null,
  "Nazwa obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "Przechowywanie wszystkich tymczasowych plików punktów kontrolnych"
 ],
 "Key": [
  null,
  "Klucz"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  "Bez wyłączania po zapisaniu punktu kontrolnego na dysku"
 ],
 "Loading logs...": [
  null,
  "Wczytywanie dzienników…"
 ],
 "Loading...": [
  null,
  "Wczytywanie…"
 ],
 "Logs": [
  null,
  "Dzienniki"
 ],
 "MAC address": [
  null,
  "Adres MAC"
 ],
 "Memory": [
  null,
  "Pamięć"
 ],
 "Memory limit": [
  null,
  "Ograniczenie pamięci"
 ],
 "Message": [
  null,
  "Komunikat"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  "Dla tego obrazu istnieje wiele etykiet. Proszę wybrać oznaczone obrazy do usunięcia."
 ],
 "Name": [
  null,
  "Nazwa"
 ],
 "No SELinux label": [
  null,
  "Brak etykiety SELinuksa"
 ],
 "No containers": [
  null,
  "Brak kontenerów"
 ],
 "No containers are using this image": [
  null,
  "Żadne kontenery nie używają tego obrazu"
 ],
 "No containers in this pod": [
  null,
  "Brak kontenerów w tym pojemniku"
 ],
 "No containers that match the current filter": [
  null,
  "Żadne kontenery nie pasują do obecnego filtru"
 ],
 "No images": [
  null,
  "Brak obrazów"
 ],
 "No images found": [
  null,
  "Nie odnaleziono obrazów"
 ],
 "No images that match the current filter": [
  null,
  "Żadne obrazy nie pasują do obecnego filtru"
 ],
 "No results for $0": [
  null,
  "Brak wyników dla zapytania „$0”"
 ],
 "No running containers": [
  null,
  "Brak uruchomionych kontenerów"
 ],
 "Only running": [
  null,
  "Tylko uruchomione"
 ],
 "Owner": [
  null,
  "Właściciel"
 ],
 "Pause": [
  null,
  "Wstrzymaj"
 ],
 "Pause the container": [
  null,
  "Wstrzymaj kontener"
 ],
 "Paused": [
  null,
  "Wstrzymane"
 ],
 "Please confirm deletion of $0": [
  null,
  "Proszę potwierdzić usunięcie $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Proszę potwierdzić usunięcie pojemnika $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Proszę potwierdzić wymuszenie usunięcia pojemnika $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Proszę potwierdzić wymuszenie usunięcia $0"
 ],
 "Please retry another term.": [
  null,
  "Proszę spróbować innych słów."
 ],
 "Please start typing to look for images.": [
  null,
  "Proszę zacząć pisać, aby wyszukać obrazy."
 ],
 "Podman containers": [
  null,
  "Kontenery Podman"
 ],
 "Podman service is not active": [
  null,
  "Usługa Podman nie jest aktywna"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Private": [
  null,
  "Prywatne"
 ],
 "Pulling": [
  null,
  "Pobieranie"
 ],
 "ReadOnly": [
  null,
  "Tylko do odczytu"
 ],
 "ReadWrite": [
  null,
  "Odczyt i zapis"
 ],
 "Remove item": [
  null,
  "Usuń element"
 ],
 "Remove on build variable": [
  null,
  "Usuń na zmiennej budowania"
 ],
 "Restart": [
  null,
  "Uruchom ponownie"
 ],
 "Restore": [
  null,
  "Przywróć"
 ],
 "Restore container $0": [
  null,
  "Przywróć kontener $0"
 ],
 "Restore with established TCP connections": [
  null,
  "Przywróć z nawiązanymi połączeniami TCP"
 ],
 "Resume": [
  null,
  "Wznów"
 ],
 "Run": [
  null,
  "Uruchom"
 ],
 "Run image": [
  null,
  "Uruchom obraz"
 ],
 "Running": [
  null,
  "Uruchomione"
 ],
 "Search by name or description": [
  null,
  "Szukaj według nazwy lub opisu"
 ],
 "Search for": [
  null,
  "Szukaj"
 ],
 "Search for an image": [
  null,
  "Znajdź obraz"
 ],
 "Searching...": [
  null,
  "Wyszukiwanie…"
 ],
 "Set container on build variables": [
  null,
  "Ustaw kontener na zmiennych budowania"
 ],
 "Shared": [
  null,
  "Współdzielone"
 ],
 "Show": [
  null,
  "Wyświetl"
 ],
 "Show intermediate images": [
  null,
  "Wyświetl pośrednie obrazy"
 ],
 "Size": [
  null,
  "Rozmiar"
 ],
 "Start": [
  null,
  "Uruchom"
 ],
 "Start podman": [
  null,
  "Uruchom usługę podman"
 ],
 "State": [
  null,
  "Stan"
 ],
 "Stop": [
  null,
  "Zatrzymaj"
 ],
 "Stopped": [
  null,
  "Zatrzymane"
 ],
 "Support preserving established TCP connections": [
  null,
  "Obsługa zachowywania nawiązanych połączeń TCP"
 ],
 "System": [
  null,
  "System"
 ],
 "System Podman service is also available": [
  null,
  "Dostępna jest także systemowa usługa Podman"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etykieta"
 ],
 "Tags": [
  null,
  "Etykiety"
 ],
 "Troubleshoot": [
  null,
  "Rozwiąż problem"
 ],
 "Type to filter…": [
  null,
  "Wyszukiwanie…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Uruchomione od $0"
 ],
 "Used by": [
  null,
  "Używane przez"
 ],
 "User": [
  null,
  "Użytkownik"
 ],
 "User Podman service is also available": [
  null,
  "Dostępna jest także usługa Podman użytkownika"
 ],
 "Value": [
  null,
  "Wartość"
 ],
 "Volumes": [
  null,
  "Woluminy"
 ],
 "With terminal": [
  null,
  "Z terminalem"
 ],
 "configured": [
  null,
  "skonfigurowane"
 ],
 "container": [
  null,
  "kontener"
 ],
 "created": [
  null,
  "utworzone"
 ],
 "exited": [
  null,
  "zakończone"
 ],
 "image": [
  null,
  "obraz"
 ],
 "in": [
  null,
  "w"
 ],
 "n/a": [
  null,
  "niedostępne"
 ],
 "not available": [
  null,
  "niedostępne"
 ],
 "paused": [
  null,
  "wstrzymane"
 ],
 "pod group": [
  null,
  "grupa pojemników"
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  "usuwanie"
 ],
 "running": [
  null,
  "uruchomione"
 ],
 "select all": [
  null,
  "zaznacz wszystko"
 ],
 "stopped": [
  null,
  "zatrzymane"
 ],
 "system": [
  null,
  "systemowa"
 ]
});
